|PyPI| |CI| |Docs| |Coverage|

OmniPath
========

This package is a Python equivalent of an R package `OmnipathR`_ for accessing web service of
`OmniPath`_ database developed by `Saezlab`_.

.. toctree::
    :caption: General
    :maxdepth: 2
    :hidden:

    installation
    api
    release_notes
    references

.. |PyPI| image:: https://img.shields.io/pypi/v/omnipath.svg
    :target: https://pypi.org/project/omnipath
    :alt: PyPI

.. |CI| image:: https://img.shields.io/github/workflow/status/michalk8/omnipath/CI/master
    :target: https://github.com/michalk8/omnipath/actions?query=workflow:CI
    :alt: CI

.. |Docs|  image:: https://img.shields.io/readthedocs/omnipath
    :target: https://omnipath.readthedocs.io/en/latest
    :alt: Documentation

.. |Coverage| image:: https://codecov.io/gh/michalk8/omnipath/branch/master/graph/badge.svg?token=5A086KQA51
    :target: https://codecov.io/gh/michalk8/omnipath
    :alt: Coverage

.. _Saezlab : https://saezlab.org/
.. _OmniPathR : https://github.com/saezlab/omnipathR
